@@ -9,6 +9,10 @@ name = "{}"
 author = "{}"
 entry = "main.sw"
 license = "Apache-2.0"
+
+[dependencies]
+std  = {{ git = "http://github.com/FuelLabs/sway-lib-std" }}
+core = {{ git = "http://github.com/FuelLabs/sway-lib-core" }}
 "#,
         project_name, real_name,
     )
@@ -32,6 +36,7 @@ license = "Apache-2.0"
 [dependencies]
 tokio = {{ version = "1.12", features = ["rt", "macros"] }}
 fuels-abigen-macro = "0.1"
+fuels-core = "0.1"
 fuels-rs = "0.1"
 fuel-gql-client = {{ version = "0.1", default-features = false }}
 fuel-tx = "0.1"
